/*|-----------------------------------------------------------|*/
/*|SKETCH FOR ESP32 UDP DATAGRAMS CONTROL USING PACKET SENDER |*/
/*|Author: MARTIN CHLEBOVEC                                   |*/
/*|Web: http://arduino.clanweb.eu/udp-control-esp32.php       |*/
/*|Board: ESP32 DevkitC v4 / ESP32 Devkit v1                  |*/
/*|Buy me coffee: paypal.me/chlebovec                         |*/
/*|Send ON or OFF string from Packet Sender for change of pin |*/
/*|-----------------------------------------------------------|*/
 
#include "WiFi.h"
#include "AsyncUDP.h"
const char* ssid = "DeinSSID";
const char* pass = "Passwort";
const int led = 2; //D pin (Build-in LED for Devkit V1)
AsyncUDP udp;
 
void setup()
{
  Serial.begin(115200);
  pinMode(led, OUTPUT);
  WiFi.disconnect(true);
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, pass);
 
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
 
  if (udp.listen(20057)) {
    Serial.print("UDP server na IP: ");
    Serial.print(WiFi.localIP());
    Serial.println(" port: 20057");
    udp.onPacket([](AsyncUDPPacket packet) {
      Serial.print("Type of UDP datagram: ");
      Serial.print(packet.isBroadcast() ? "Broadcast" : packet.isMulticast() ? "Multicast" : "Unicast");
      Serial.print(", Sender: ");
      Serial.print(packet.remoteIP());
      Serial.print(":");
      Serial.print(packet.remotePort());
      Serial.print(", Receiver: ");
      Serial.print(packet.localIP());
      Serial.print(":");
      Serial.print(packet.localPort());
      Serial.print(", Message length: ");
      Serial.print(packet.length()); //dlzka spravy
      Serial.print(", Payload: ");
      Serial.write(packet.data(), packet.length());
      Serial.println();
      String myString = (const char*)packet.data();
      if (myString.startsWith("In_a=00001")) {
        Serial.println("Action: Turning ON relay");
        digitalWrite(led, HIGH);
      } else if (myString.startsWith("In_a=00000")) {
        Serial.println("Action: Turning OFF relay");
        digitalWrite(led, LOW);
      }
      packet.printf("ESP32 received %u bytes of data", packet.length()); //odpoved odosielatelovi
    });
  }
}
 
void loop()
{
  delay(10000);
}